#!/usr/bin/perl
#
# Convert the TVbegone files distributed with unzap
# http://www.lochraster.org/unzap/?en
# into a data structure suitable for HPunzap


# Adjustment macro for HP 200LX timed with a stopwatch.
# (As interrupts are disabled the RTC doesn't work.)
# 1000 numbers of n=1000 timings take 10.19"s
# 1000 numbers of n=2000 timings take 19.48"s
# 1000 numbers of n=4000 timings take 38.60"s
# Therefore each timing lasts 9.65us

$adjust = 9.65;

open(C, '>cmds.c') || die;
open(H, '>cmds.h') || die;
open(D, '>codes.c') || die;

print H q<
struct cmd {
	unsigned int frequency;	/* Modulation frequency */
	int repeat;		/* Times to repeat */
	unsigned int pause;	/* Pause between repetitions */
	int n;			/* Number of timing elements */
	unsigned int *timings;	/* Code timings (on, off) ... */
	char *name;
};

extern struct cmd cmds[];
>;

print C '
/* Automatically generated file. */
#include "cmds.h"

struct cmd cmds[] = {
';

foreach $f (<unzap/db/*.yaml>) {
	$name = $f;
	$name =~ s,unzap/db/,,;
	$name =~ s,\.yaml,,;
	$name =~ s,\W,,g;
	print H "extern unsigned int ${name}[];\n";
	print D "unsigned int ${name}[] = {";
	open(IN, $f) || die "Unable to open $f: $!\n";
	undef $frequency;
	undef $repeat;
	undef $pause;
	$n = 0;
	while (<IN>) {
		$frequency = $1 if (/^frequency: (\d+)/);
		$repeat = $1 if (/^repeat: (\d+)/);
		$pause = $1 if (/^repeat_delay: (\d+)/);
		if (/^\-\s*\[\s*(\d+)\,\s*(\d+)\s*\]/) {
			$on = $1;
			$off = $2;
			$n += 2;
			$on = int($on / $adjust);
			$off = int($off / $adjust);
			die "On $on too large in $f\n" if ($on > 65535);
			die "Off $off too large in $f\n" if ($off > 65535);
			print D "$on, $off, ";
		}
	}
	die "Frequency not defined in $f\n" unless defined($frequency);
	if (!defined($repeat)) {
		$repeat = 0;
		$pause = 0;
	} else {
		die "Pause not defined in $f\n" unless defined($pause);
	}
	die "Codes not defined in $f\n" unless ($n > 0);
	$pause = int($pause / $adjust);
	die "Pause $pause too large in $f\n" if ($pause > 65535);
	print C qq(\t{$frequency, $repeat, $pause, $n, $name, "$name"},\n);
	print D "};\n";
	$ncmd++;
}
print C "};\n";
print H "\n#define NCMD $ncmd\n";
