/*-
 * HP-200LX TV unzap
 *
 * (C) Copyright 1992-2009 Diomidis Spinellis.  All rights reserved.
 *
 * Permission to use, copy, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * $Id$
 *
 */

#include "serial.h"
#include "hpir.h"

#include "cmds.h"

static void
enable_serial_power(void)
{
	_asm {
		mov ax, 0x4a01
		int 0x15
		mov ax, 0x4901
		int 0x15
	}
}

static void
disable_serial_power(void)
{
	_asm {
		mov ax, 0x4900
		int 0x15
		mov ax, 0x4a00
		int 0x15
	}
}

static void
enable_light_sleep(void)
{
	_asm mov ax, 4e01h
	_asm int 15h
}

static void
disable_light_sleep(void)
{
	_asm mov ax, 4e00h
	_asm int 15h
}

static void
ir_start_send(unsigned int modfr)
{
	#define CLOCK 1840000
	unsigned int divisor = (unsigned int)((unsigned long)CLOCK / modfr);

	disable_light_sleep();
	enable_serial_power();
	_disable();
	outp(HIR, IRCNT);
	outp(HDR, 0);
	outp(HIR, IRFMAT);
	outp(HDR, MDLTE | MDSEL);
	outp(LCR, DLAB | WLS0 | WLS1);
	outp(DLM, divisor / 256);
	outp(DLL, divisor % 256);
	outp(LCR, 0);
}

static void
ir_start_receive(void)
{
	disable_light_sleep();
	enable_serial_power();
	_disable();
}

static void
ir_end(void)
{
	outp(HIR, IRCNT);
	outp(HDR, 0);
	outp(HIR, IRFMAT);
	outp(HDR, 0);
	outp(LCR, DLAB | WLS0 | WLS1);
	outp(DLM, 0);
	outp(DLL, 0);
	outp(LCR, 0);
	_enable();
	enable_light_sleep();
	disable_serial_power();
}

static void
pause(unsigned int n)
{
	int i;

	for (i = 0; i < n; i++)
		_asm nop
}

/*
 * Set the infrared red modulation frequency to modfr.
 * Send an array of n timings repeated the specified times.
 * Timing values are given in loop iterations and consist of an on time
 * followed by an off time.
 */
static void
play(unsigned int modfr, unsigned int *timings, int n, int repeat, unsigned int pause_n)
{
	int i, j, k, r;
	unsigned int *t;

	ir_start_send(modfr);
	outp(HIR, IRCNT);
	for (r = 0; r < repeat; r++) {
		t = timings;
		for (i = 0; i < n; i += 2) {
			/* High bit */
			k = *t++;
			outp(HDR, MDLD);
			for (j = 0; j < k; j++)
				_asm nop
			/* Low bit */
			outp(HDR, 0);
			k = *t++;
			for (j = 0; j < k; j++)
				_asm nop
		}
		pause(pause_n);
	}
	ir_end();
}


int
main(int argc, char *argv[])
{
	int i;

	for (i = 0; i < NCMD; i++) {
		puts(cmds[i].name);
		play(cmds[i].frequency, cmds[i].timings, cmds[i].n, cmds[i].repeat + 1, cmds[i].pause);
		pause(20000);
	}
	return 0;
}
