/*
 * The structure of the HP 100 LX infrared port
 * (C) Copyright 1993, 1994 Diomidis D. Spinellis.  All rights reserved.
 *
 * Permission to use, copy, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 */

#define HIR	0x22	/* HORNET index register */
#define HDR	0x23	/* HORNET data register */

#define IRFMAT 0x10	/* Register HORNET index */
#define RED	1	/* when set activates REDEYE transmit mode. */
#define MDLTE	2	/* when set activates Modulated communication */
#define IRURT	4	/* when set activates IR UART communication mode. */
#define MDSEL	8	/* used to select the modulation source */
#define PMOD	16	/* used in IR UART mode to select pulse type  */
#define LBF	32	/* LED Buffer Full. */
#define ELBE	64	/* Enable Interrupt on LBR bit Empty (LBF clear */
#define INV	128	/* When set invert LED sense. */

#define IRCNT 0x11	/* Register HORNET index */
#define LED	1	/* 1 turn on LED driver, used for sw controlled */
#define LBR	2	/* 0 transmit "off" half-bit in REDEYE format */
#define MDLD	4	/* 1 gate output when in modulated communication mode */
#define IRE	32	/* 1 IR event has occurred, software cleared  */
#define EIRI	64	/* 1 enable IR interrupt on IRI = 1 */
#define IRI	128	/* state of the IRI pin (read only) */


#define out_high()	outp(HDR, MDLD)
#define out_low()	outp(HDR, 0)

#define in_start() (outp(IRFMAT, 0), outp(IRCNT, 0))

/*
 * In order to filter out the 40KHz carrier we look at the active
 * high IRE (interrupt event) bit 0x20, and ignore the active low
 * IRI (infrared input) bit 0x80.
 * After each IRE, we reset IRE; wait for 25us for the carrier to
 * send another IR pulse, and then check IRE again.
 */
#define in_high() 	(inp(HDR) & 0x20)
#define in_low()	(inp(HDR) == 0x80)
#define in_reset() 	(outp(HDR, 0x80))
