/* Base address of card */
#define BASE 0x3f8

/* Line control register (read/write) */
#define LCR (BASE + 3)
/* 
 * Word length select bit 
 * Bit 1 Bit 0	Word length
 * 0	 0	5
 * 0	 1	6
 * 1	 0	7
 * 1	 1	8
 */
#define WLS0 1
#define WLS1 2
/* Number of stop bits 0 == 1, 1 == 2 */
#define STB 4
/* Parity enable 1 == enable */
#define PEN 8
/* Even parity select 1 == even */
#define EPS 16
/* Stick parity 1 == send EPS as parity */
#define STICK 32
/* Set break 1 == send break */
#define BREAK 64
/* Divisor latch access bit 1 == access divisor */
#define DLAB 128

/* Baud rate generator.  Divisor = frequency input / ( baud * 16) */
/* Clock on the 95LX is 1.8MHz.  Se the divisor to 0 to save power */
/* Divisor latch least sigificant bit DLAB == 1*/
#define DLL (BASE)
/* Divisor latch most sigificant bit DLAB == 1*/
#define DLM (BASE+1)

/* Line status register */
#define LSR (BASE+5)
/* Data ready.  1 == ready byte to read.  Is set to 0 by reading it.  */
#define DR 1
/* Overrun error. 1 == error */
#define OE 2
/* Parity error */
#define PE 4
/* Framing error (no stop bit) */
#define FE 8
/* Break interrupt (set to 1 when a break is detected) */
#define BI 16
/* Trasnitter Holding Register Empty.  1 == ready to accept character */
#define THRE 32
/* Transimiter shift register empty */
#define TSRE 64

/* Interrupt identification register */
#define IIR (BASE+2)
/* 0 if interrupt pending */
#define INTPEND 1
/* Interrupt identification */
#define INT1 2
#define INT2 4

/* Interrupt enable register */
#define IER (BASE + 1)
#define RXDATA 1
#define TXDATA 2
#define RXSTATUS 4
#define MODEMSTATUS 8

/* Modem control register */
#define MCR (BASE + 4)
#define DTR 1
#define RTS 2
#define OUT1 4
#define OUT2 8
#define LOOP 16

/* Modem status register */
#define MSR (BASE+6)
#define DCTS 1
#define DDSR 2
#define TERI 4
#define DRLSD 8
#define CTS 16
#define DSD 32
#define RI 64
#define RLSD 128

/* Receiver buffer register (read only, DLAB == 0) */
#define RBR (BASE)
/* Transmitter holding register (write only, DLAB == 0) */
#define THR (BASE)

